@@ -1,7 +1,8 @@
 import os, sys
-print('moofei', sys.argv)
-print(os.getcwd())
-#ҲԽpkgΪһPackageִУpython -m pkg
+print('usage:')
+for method in ('find', 'valid'):
+    print(' '*4+' '.join([sys.executable, '-m', 'moofei.'+method, '-h']))
+
 
 if len(sys.argv)>2:
     if sys.argv[1]==":find":
